@@ -1,5 +1,5 @@
 #include <stdio.h>
-#include <R_ext/Applic.h>
+#include <R_ext/Linpack.h>
 
 #include "glmmml.h"
 #include "fun.h"
